<?php

namespace Annie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Event\Models\EventCollage;

class EventCollagePolicy
{

    /**
     * Determine if the given user can view the event_collage.
     *
     * @param UserPolicy $user
     * @param EventCollage $event_collage
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventCollage $event_collage)
    {
        if ($user->canDo('event.event_collage.view') && $user->isAdmin()) {
            return true;
        }

        return $event_collage->user_id == user_id() && $event_collage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_collage.
     *
     * @param UserPolicy $user
     * @param EventCollage $event_collage
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.event_collage.create');
    }

    /**
     * Determine if the given user can update the given event_collage.
     *
     * @param UserPolicy $user
     * @param EventCollage $event_collage
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventCollage $event_collage)
    {
        if ($user->canDo('event.event_collage.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_collage->user_id == user_id() && $event_collage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_collage.
     *
     * @param UserPolicy $user
     * @param EventCollage $event_collage
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventCollage $event_collage)
    {
        return $event_collage->user_id == user_id() && $event_collage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_collage.
     *
     * @param UserPolicy $user
     * @param EventCollage $event_collage
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventCollage $event_collage)
    {
        if ($user->canDo('event.event_collage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_collage.
     *
     * @param UserPolicy $user
     * @param EventCollage $event_collage
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventCollage $event_collage)
    {
        if ($user->canDo('event.event_collage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
