<?php

namespace Annie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Event\Models\EventCommunity;

class EventCommunityPolicy
{

    /**
     * Determine if the given user can view the event_community.
     *
     * @param UserPolicy $user
     * @param EventCommunity $event_community
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventCommunity $event_community)
    {
        if ($user->canDo('event.event_community.view') && $user->isAdmin()) {
            return true;
        }

        return $event_community->user_id == user_id() && $event_community->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_community.
     *
     * @param UserPolicy $user
     * @param EventCommunity $event_community
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.event_community.create');
    }

    /**
     * Determine if the given user can update the given event_community.
     *
     * @param UserPolicy $user
     * @param EventCommunity $event_community
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventCommunity $event_community)
    {
        if ($user->canDo('event.event_community.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_community->user_id == user_id() && $event_community->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_community.
     *
     * @param UserPolicy $user
     * @param EventCommunity $event_community
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventCommunity $event_community)
    {
        return $event_community->user_id == user_id() && $event_community->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_community.
     *
     * @param UserPolicy $user
     * @param EventCommunity $event_community
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventCommunity $event_community)
    {
        if ($user->canDo('event.event_community.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_community.
     *
     * @param UserPolicy $user
     * @param EventCommunity $event_community
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventCommunity $event_community)
    {
        if ($user->canDo('event.event_community.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
