<?php

namespace Annie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Event\Models\EventLead;

class EventLeadPolicy
{

    /**
     * Determine if the given user can view the event_lead.
     *
     * @param UserPolicy $user
     * @param EventLead $event_lead
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventLead $event_lead)
    {
        if ($user->canDo('event.event_lead.view') && $user->isAdmin()) {
            return true;
        }

        return $event_lead->user_id == user_id() && $event_lead->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_lead.
     *
     * @param UserPolicy $user
     * @param EventLead $event_lead
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.event_lead.create');
    }

    /**
     * Determine if the given user can update the given event_lead.
     *
     * @param UserPolicy $user
     * @param EventLead $event_lead
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventLead $event_lead)
    {
        if ($user->canDo('event.event_lead.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_lead->user_id == user_id() && $event_lead->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_lead.
     *
     * @param UserPolicy $user
     * @param EventLead $event_lead
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventLead $event_lead)
    {
        return $event_lead->user_id == user_id() && $event_lead->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_lead.
     *
     * @param UserPolicy $user
     * @param EventLead $event_lead
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventLead $event_lead)
    {
        if ($user->canDo('event.event_lead.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_lead.
     *
     * @param UserPolicy $user
     * @param EventLead $event_lead
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventLead $event_lead)
    {
        if ($user->canDo('event.event_lead.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
