<?php

namespace Annie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Event\Models\Event;

class EventPolicy
{

    /**
     * Determine if the given user can view the event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function view(UserPolicy $user, Event $event)
    {
        if ($user->canDo('event.event.view') && $user->isAdmin()) {
            return true;
        }

        return $event->user_id == user_id() && $event->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.event.create');
    }

    /**
     * Determine if the given user can update the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function update(UserPolicy $user, Event $event)
    {
        if ($user->canDo('event.event.edit') && $user->isAdmin()) {
            return true;
        }

        return $event->user_id == user_id() && $event->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Event $event)
    {
        return $event->user_id == user_id() && $event->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Event $event)
    {
        if ($user->canDo('event.event.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event.
     *
     * @param UserPolicy $user
     * @param Event $event
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Event $event)
    {
        if ($user->canDo('event.event.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
