<?php

namespace Annie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Event\Models\EventSchool;

class EventSchoolPolicy
{

    /**
     * Determine if the given user can view the event_school.
     *
     * @param UserPolicy $user
     * @param EventSchool $event_school
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventSchool $event_school)
    {
        if ($user->canDo('event.event_school.view') && $user->isAdmin()) {
            return true;
        }

        return $event_school->user_id == user_id() && $event_school->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_school.
     *
     * @param UserPolicy $user
     * @param EventSchool $event_school
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.event_school.create');
    }

    /**
     * Determine if the given user can update the given event_school.
     *
     * @param UserPolicy $user
     * @param EventSchool $event_school
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventSchool $event_school)
    {
        if ($user->canDo('event.event_school.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_school->user_id == user_id() && $event_school->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_school.
     *
     * @param UserPolicy $user
     * @param EventSchool $event_school
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventSchool $event_school)
    {
        return $event_school->user_id == user_id() && $event_school->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_school.
     *
     * @param UserPolicy $user
     * @param EventSchool $event_school
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventSchool $event_school)
    {
        if ($user->canDo('event.event_school.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_school.
     *
     * @param UserPolicy $user
     * @param EventSchool $event_school
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventSchool $event_school)
    {
        if ($user->canDo('event.event_school.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
