<?php

namespace Annie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Event\Models\EventSetting;

class EventSettingPolicy
{

    /**
     * Determine if the given user can view the event_setting.
     *
     * @param UserPolicy $user
     * @param EventSetting $event_setting
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventSetting $event_setting)
    {
        if ($user->canDo('event.event_setting.view') && $user->isAdmin()) {
            return true;
        }

        return $event_setting->user_id == user_id() && $event_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_setting.
     *
     * @param UserPolicy $user
     * @param EventSetting $event_setting
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.event_setting.create');
    }

    /**
     * Determine if the given user can update the given event_setting.
     *
     * @param UserPolicy $user
     * @param EventSetting $event_setting
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventSetting $event_setting)
    {
        if ($user->canDo('event.event_setting.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_setting->user_id == user_id() && $event_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_setting.
     *
     * @param UserPolicy $user
     * @param EventSetting $event_setting
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventSetting $event_setting)
    {
        return $event_setting->user_id == user_id() && $event_setting->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_setting.
     *
     * @param UserPolicy $user
     * @param EventSetting $event_setting
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventSetting $event_setting)
    {
        if ($user->canDo('event.event_setting.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_setting.
     *
     * @param UserPolicy $user
     * @param EventSetting $event_setting
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventSetting $event_setting)
    {
        if ($user->canDo('event.event_setting.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
