<?php

namespace Annie\Event\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Event\Models\EventSocialPartner;

class EventSocialPartnerPolicy
{

    /**
     * Determine if the given user can view the event_social_partner.
     *
     * @param UserPolicy $user
     * @param EventSocialPartner $event_social_partner
     *
     * @return bool
     */
    public function view(UserPolicy $user, EventSocialPartner $event_social_partner)
    {
        if ($user->canDo('event.event_social_partner.view') && $user->isAdmin()) {
            return true;
        }

        return $event_social_partner->user_id == user_id() && $event_social_partner->user_type == user_type();
    }

    /**
     * Determine if the given user can create a event_social_partner.
     *
     * @param UserPolicy $user
     * @param EventSocialPartner $event_social_partner
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('event.event_social_partner.create');
    }

    /**
     * Determine if the given user can update the given event_social_partner.
     *
     * @param UserPolicy $user
     * @param EventSocialPartner $event_social_partner
     *
     * @return bool
     */
    public function update(UserPolicy $user, EventSocialPartner $event_social_partner)
    {
        if ($user->canDo('event.event_social_partner.edit') && $user->isAdmin()) {
            return true;
        }

        return $event_social_partner->user_id == user_id() && $event_social_partner->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given event_social_partner.
     *
     * @param UserPolicy $user
     * @param EventSocialPartner $event_social_partner
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, EventSocialPartner $event_social_partner)
    {
        return $event_social_partner->user_id == user_id() && $event_social_partner->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given event_social_partner.
     *
     * @param UserPolicy $user
     * @param EventSocialPartner $event_social_partner
     *
     * @return bool
     */
    public function verify(UserPolicy $user, EventSocialPartner $event_social_partner)
    {
        if ($user->canDo('event.event_social_partner.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given event_social_partner.
     *
     * @param UserPolicy $user
     * @param EventSocialPartner $event_social_partner
     *
     * @return bool
     */
    public function approve(UserPolicy $user, EventSocialPartner $event_social_partner)
    {
        if ($user->canDo('event.event_social_partner.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
